@@ -1,8 +1,8 @@
 /* info-utils.c -- miscellanous.
-   $Id: info-utils.c 6327 2015-06-09 11:12:41Z gavin $
+   $Id: info-utils.c 7818 2017-06-03 20:52:27Z gavin $
 
    Copyright 1993, 1998, 2003, 2004, 2007, 2008, 2009, 2011, 2012,
-   2013, 2014, 2015 Free Software Foundation, Inc.
+   2013, 2014, 2015, 2016, 2017 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -43,10 +43,6 @@ extern char * rpl_nl_langinfo (nl_item);
 #define va_copy(ap1,ap2) memcpy((&ap1),(&ap2),sizeof(va_list))
 #endif
 
-/* When non-zero, various display and input functions handle ISO Latin
-   character sets correctly. */
-int ISO_Latin_p = 1;
-
 /* Variable which holds the most recent filename parsed as a result of
    calling info_parse_xxx (). */
 char *info_parsed_filename = NULL;
@@ -56,8 +52,8 @@ char *info_parsed_filename = NULL;
 char *info_parsed_nodename = NULL;
 
 /* Read a filename surrounded by "(" and ")", accounting for matching
-   characters.  Return length of read filename.  On error, set *FILENAME
-   to null and return 0.  */
+   characters, and place it in *FILENAME if FILENAME is not null.  Return 
+   length of read filename.  On error, set *FILENAME to null and return 0.  */
 int
 read_bracketed_filename (char *string, char **filename)
 {
@@ -65,7 +61,6 @@ read_bracketed_filename (char *string, char **filename)
   int count = 0; /* Level of nesting. */
   int first_close = -1; /* First ")" encountered. */
 
-  *filename = 0;
   if (*string != '(')
     return 0;
 
@@ -91,13 +86,19 @@ read_bracketed_filename (char *string, char **filename)
   if (count > 0)
     {
       if (first_close == -1)
-        return 0;
+        {
+          if (filename)
+            *filename = 0;
+          return 0;
+        }
       i = first_close;
     }
 
-  /* Remember parsed filename. */
-  *filename = xcalloc (1, i + 1);
-  memcpy (*filename, string, i);
+  if (filename)
+    {
+      *filename = xcalloc (1, i + 1);
+      memcpy (*filename, string, i);
+    }
 
   return i + 2; /* Length of filename plus "(" and ")". */
 }
@@ -126,11 +127,10 @@ info_parse_node (char *string)
 
   /* Parse out nodename. */
   string += skip_whitespace_and_newlines (string);
-  nodename_len = strlen (string);
+  nodename_len = read_quoted_string (string, "", 0, &info_parsed_nodename);
 
   if (nodename_len != 0)
     {
-      info_parsed_nodename = xstrdup (string);
       canonicalize_whitespace (info_parsed_nodename);
     }
 }
@@ -141,9 +141,7 @@ info_parse_node (char *string)
    TERMINATOR is an empty string, finish at a null character.   LINES is
    the number of lines that the string can span.  If LINES is zero, there is no
    limit.  Return length of string including any quoting characters.  Return
-   0 if input was invalid.
-
-   TODO: Decide on best method of quoting. */
+   0 if input was invalid. */
 long
 read_quoted_string (char *start, char *terminator, int lines, char **output)
 {
@@ -184,13 +182,13 @@ read_quoted_string (char *start, char *terminator, int lines, char **output)
           (*output)[len] = '\0';
         }
     }
-#ifdef QUOTE_NODENAMES
   else
     {
       len = strcspn (start + 1, "\177");
 
       if (*terminator && !(start + 1)[len])
         {
+          /* No closing 177 byte. */
           len = 0;
           *output = 0;
         }
@@ -199,17 +197,10 @@ read_quoted_string (char *start, char *terminator, int lines, char **output)
           *output = xmalloc (len + 1);
           strncpy (*output, start + 1, len);
           (*output)[len] = '\0';
+          len += 2; /* Count the two 177 bytes. */
         }
 
-      len += 2;
     }
-#else /* ! QUOTE_NODENAMES */
-  else
-    {
-      *output = xstrdup ("");
-      len = 0;
-    }
-#endif
 
   if (nl)
     *nl = saved_char;
@@ -225,45 +216,32 @@ read_quoted_string (char *start, char *terminator, int lines, char **output)
 
 /* Get the entry associated with LABEL in the menu of NODE.  Return a
    pointer to the ENTRY if found, or null.  Return value should not
-   be freed by caller. */
+   be freed by caller.  If SLOPPY, allow initial matches, like
+   "Buffers" for a LABEL "buffer". */
 REFERENCE *
 info_get_menu_entry_by_label (NODE *node, char *label, int sloppy) 
 {
   register int i;
+  int best_guess = -1;
   REFERENCE *entry;
   REFERENCE **references = node->references;
 
   if (!references)
     return 0;
 
-  /* First look for an exact match. */
   for (i = 0; (entry = references[i]); i++)
     {
-      if (REFERENCE_MENU_ITEM != entry->type) continue;
-      if (strcmp (label, entry->label) == 0)
-        return entry;
+      if (entry->type != REFERENCE_MENU_ITEM)
+        continue;
+      if (mbscasecmp (label, entry->label) == 0)
+        return entry; /* Exact, case-insensitive match. */
+      else if (sloppy && best_guess == -1
+               && (mbsncasecmp (entry->label, label, strlen (label)) == 0))
+        best_guess = i;
     }
 
-  /* If the item wasn't found, search the list sloppily.  Perhaps this
-     user typed "buffer" when they really meant "Buffers". */
-  if (sloppy)
-    {
-      int i;
-      int best_guess = -1;
-
-      for (i = 0; (entry = references[i]); i++)
-        {
-          if (REFERENCE_MENU_ITEM != entry->type) continue;
-          if (mbscasecmp (label, entry->label) == 0)
-            return entry; /* Exact, case-insensitive match. */
-          else if (best_guess == -1
-                && (mbsncasecmp (entry->label, label, strlen (label)) == 0))
-              best_guess = i;
-        }
-
-      if (!entry && best_guess != -1)
-        return references[best_guess];
-    }
+  if (sloppy && best_guess != -1)
+    return references[best_guess];
 
   return 0;
 }
@@ -489,13 +467,14 @@ ansi_escape (mbi_iterator_t iter, size_t *plen)
   return 0;
 }
 
-static struct text_buffer printed_rep = {}; /* Initialize with all zeroes. */
+static struct text_buffer printed_rep = { 0 };
 
 /* Return pointer to string that is the printed representation of character
    (or other logical unit) at ITER if it were printed at screen column
-   PL_CHARS.  Use ITER_SETBYTES (info-utils.h) on ITER if byte length is
-   different.  If ITER points at an end-of-line character, set *DELIM to this
-   character.  *PCHARS gets the number of screen columns taken up by
+   PL_CHARS.  Use ITER_SETBYTES (info-utils.h) on ITER if we need to advance 
+   past a unit that the multibyte iteractor doesn't know about (like an ANSI 
+   escape sequence).  If ITER points at an end-of-line character, set *DELIM to 
+   this character.  *PCHARS gets the number of screen columns taken up by
    outputting the return value, and *PBYTES the number of bytes in returned
    string.  Return value is not null-terminated.  Return value must not be
    freed by caller. */
@@ -503,7 +482,6 @@ char *
 printed_representation (mbi_iterator_t *iter, int *delim, size_t pl_chars,
                         size_t *pchars, size_t *pbytes) 
 {
-  int printable_limit = ISO_Latin_p ? 255 : 127;
   struct text_buffer *rep = &printed_rep;
 
   char *cur_ptr = (char *) mbi_cur_ptr (*iter);
@@ -569,20 +547,10 @@ printed_representation (mbi_iterator_t *iter, int *delim, size_t pl_chars,
       text_buffer_add_char (rep, *cur_ptr | 0x40);
       return text_buffer_base (rep);
     }
-  /* Show META-x as "\370".  */
-  else if (*(unsigned char *)cur_ptr > printable_limit)
-    {
-      *pchars = 4;
-      *pbytes = 4;
-      text_buffer_printf (rep, "\\%0o", *cur_ptr);
-      return text_buffer_base (rep);
-    }
   else if (*cur_ptr == DEL)
     {
-      *pchars = 2;
-      *pbytes = 2;
-      text_buffer_add_char (rep, '^');
-      text_buffer_add_char (rep, '?');
+      *pchars = 0;
+      *pbytes = 0;
       return text_buffer_base (rep);
     }
   else
@@ -594,7 +562,7 @@ printed_representation (mbi_iterator_t *iter, int *delim, size_t pl_chars,
          terminal. */
       *pchars = 4;
       *pbytes = 4;
-      text_buffer_printf (rep, "\\%0o", *cur_ptr);
+      text_buffer_printf (rep, "\\%o", *(unsigned char *)cur_ptr);
       return text_buffer_base (rep);
     }
 }
@@ -612,7 +580,11 @@ int preprocess_nodes_p;
 /* Whether contents of nodes should be rewritten. */
 static int rewrite_p;
 
-static char *input_start, *inptr;
+/* inptr is moved forward through the body of a node. */
+static char *inptr;
+
+/* Pointer to first byte of node (after node separator). */
+static char *input_start;
 
 /* Number of bytes in node contents. */
 static size_t input_length;
@@ -623,10 +595,12 @@ struct text_buffer output_buf;
    a result of byte counts changing due to character encoding conversion or
    inserted/deleted text. */
 static TAG **anchor_to_adjust;
-static int node_offset; /* Offset within file buffer of first byte of node. */
+/* Offset within file buffer of first byte of node, used for anchor
+   adjustment. */
+static int node_offset;
 
-/* Difference between the number of bytes input in the file and
-   bytes output.  If !rewrite_p, this should stay 0. */
+/* Difference so far between the number of bytes input in the file and
+   bytes output.  Used to adjust the values of anchors in nodes. */
 static long int output_bytes_difference;
 
 /* Whether we are converting the character encoding of the file. */
@@ -792,6 +766,10 @@ degrade_utf8 (char **from, size_t *from_left)
     {"\xC3\xAB","e\""},  /* Lower case letter e with diaeresis */
     {"\xC3\xB6","o\""},  /* Lower case letter o with diaeresis */
     {"\xC3\xBC","u\""},  /* Lower case letter u with diaeresis */
+    {"\xC3\x84", "A\""},  /* Upper case letter A with diaeresis. */
+    {"\xC3\x96", "O\""},  /* Upper case letter O with diaeresis. */
+    {"\xC3\x9c", "U\""},  /* Upper case letter U with diaeresis. */
+
     {"\xC3\xB1","n~"},  /* Lower case letter n with tilde */
     {"\xC3\x87","C,"},  /* Upper case letter C with cedilla */
     {"\xC3\xA7","c,"},  /* Lower case letter c with cedilla */
@@ -840,14 +818,14 @@ copy_converting (long n)
 #if !HAVE_ICONV
   return 0;
 #else
-  size_t bytes_left;
+  size_t bytes_left, orig_bytes_left;
   int extra_at_end;
   size_t iconv_ret;
   long output_start;
 
   size_t utf8_char_free; 
   char utf8_char[4]; /* Maximum 4 bytes in a UTF-8 character */
-  char *utf8_char_ptr;
+  char *utf8_char_ptr, *orig_inptr;
   size_t i;
   
   /* Use n as an estimate of how many bytes will be required
@@ -857,12 +835,18 @@ copy_converting (long n)
   output_start = text_buffer_off (&output_buf);
   bytes_left = n;
   extra_at_end = 0;
-  while (bytes_left >= 0)
+  while (1)
     {
       iconv_ret = text_buffer_iconv (&output_buf, iconv_to_output,
-                                     &inptr, &bytes_left);
+                                     (ICONV_CONST char **)&inptr, &bytes_left);
 
-      if (iconv_ret != (size_t) -1)
+      /* Make sure libiconv flushes out the last converted character.
+	 This is required when the conversion is stateful, in which
+	 case libiconv might not output the last character, waiting to
+	 see whether it should be combined with the next one.  */
+      if (iconv_ret != (size_t) -1
+	  && text_buffer_iconv (&output_buf, iconv_to_output,
+				NULL, NULL) != (size_t) -1)
         /* Success: all of input converted. */
         break;
 
@@ -874,9 +858,6 @@ copy_converting (long n)
              and try again. */
           text_buffer_alloc (&output_buf, n);
           continue;
-        case EILSEQ:
-          /* Byte sequence in input buffer not recognized. */
-          break;
         case EINVAL:
           /* Incomplete byte sequence at end of input buffer.  Try to read
              more. */
@@ -895,16 +876,21 @@ copy_converting (long n)
               bytes_left = 0;
             }
           continue;
-        default: /* Unknown error - abort */
-          info_error (_("Error converting file character encoding."));
+        default: /* Unknown error */
+          info_error (_("Error converting file character encoding"));
 
           /* Skip past current input and hope we don't get an
              error next time. */
           inptr += bytes_left;
           return 0;
+        case EILSEQ:
+          /* Byte sequence in input not recognized.  Degrade to ASCII.  */
+          break;
         }
 
-      /* Degrade to ASCII. */
+      /* Flush any waiting input in iconv_to_output and enter the
+         default shift state. */
+      text_buffer_iconv (&output_buf, iconv_to_output, NULL, NULL);
       
       if (file_is_in_utf8)
         {
@@ -922,25 +908,47 @@ copy_converting (long n)
       /* We want to read exactly one character.  Do this by
          restricting size of output buffer. */
       utf8_char_ptr = utf8_char;
+      orig_inptr = inptr;
+      orig_bytes_left = bytes_left;
       for (i = 1; i <= 4; i++)
         {
           utf8_char_free = i;
-          iconv_ret = iconv (iconv_to_utf8, &inptr, &bytes_left,
-                             &utf8_char_ptr, &utf8_char_free);
-          /* If we managed to write a character: */
-          if (utf8_char_ptr > utf8_char) break;
+          errno = 0;
+          iconv_ret = iconv (iconv_to_utf8, (ICONV_CONST char **)&inptr,
+                             &bytes_left, &utf8_char_ptr, &utf8_char_free);
+          if ((iconv_ret == (size_t) -1 && errno != E2BIG)
+              /* If we managed to convert a character: */
+              || utf8_char_ptr > utf8_char)
+            break;
         }
 
       /* errno == E2BIG if iconv ran out of output buffer,
          which is expected. */
       if (iconv_ret == (size_t) -1 && errno != E2BIG)
-        /* Character is not recognized.  Copy a single byte. */
-        copy_direct (1);
+	{
+	  /* Character is not recognized.  Copy a single byte.  */
+	  inptr = orig_inptr;	/* iconv might have incremented inptr  */
+	  copy_direct (1);
+	  bytes_left = orig_bytes_left - 1;
+	}
       else
         {
           utf8_char_ptr = utf8_char;
           /* i is width of UTF-8 character */
           degrade_utf8 (&utf8_char_ptr, &i);
+	  /* If we are done, make sure iconv flushes the last character.  */
+	  if (bytes_left <= 0)
+	    {
+	      utf8_char_ptr = utf8_char;
+	      i = 4;
+	      iconv (iconv_to_utf8, NULL, NULL,
+		     &utf8_char_ptr, &utf8_char_free);
+	      if (utf8_char_ptr > utf8_char)
+		{
+		  utf8_char_ptr = utf8_char;
+		  degrade_utf8 (&utf8_char_ptr, &i);
+		}
+	    }
         }
     }
 
@@ -982,8 +990,8 @@ copy_input_to_output (long n)
 
               if (anchor_to_adjust)
                 {
-                  char *first_anchor = input_start - node_offset
-                                       + (*anchor_to_adjust)->nodestart;
+                  char *first_anchor = input_start
+                             + (*anchor_to_adjust)->nodestart - node_offset;
 
                   /* If there is an anchor in the input: */
                   if (first_anchor < inptr + bytes_left)
@@ -1018,7 +1026,8 @@ copy_input_to_output (long n)
                    = (*anchor_to_adjust)->nodestart - output_bytes_difference;
 
                 anchor_to_adjust++;
-                if (!*anchor_to_adjust || (*anchor_to_adjust)->nodelen != 0)
+                if (!*anchor_to_adjust
+                    || (*anchor_to_adjust)->cache.nodelen != 0)
                   {
                     anchor_to_adjust = 0;
                     break;
@@ -1082,157 +1091,109 @@ skip_tag_contents (long n)
     }
 }
 
-/* ANSI escape codes */
-#define ANSI_UNDERLINING_OFF "\033[24m"
-#define ANSI_UNDERLINING_ON  "\033[4m"
-
-/* Turn off underlining */
-static void
-underlining_off (void)
-{
-  write_extra_bytes_to_output (ANSI_UNDERLINING_OFF,
-                               strlen (ANSI_UNDERLINING_OFF));
-}
-
-/* Turn on underlining */
-static void
-underlining_on (void)
-{
-  write_extra_bytes_to_output (ANSI_UNDERLINING_ON,
-                               strlen (ANSI_UNDERLINING_ON));
-}
-
 /* Read first line of node and set next, prev and up. */
 static void
 parse_top_node_line (NODE *node)
 {
-  char **store_in, *dummy = 0;
+  char **store_in = 0;
+  char *nodename;
+  char *ptr;
   int value_length;
 
   /* If the first line is empty, leave it in.  This is the case
      in the index-apropos window. */
-  if (*inptr == '\n')
-    {
-      return;
-    }
+  if (*node->contents == '\n')
+    return;
 
   node->next = node->prev = node->up = 0;
+  ptr = node->contents;
 
   while (1)
     {
       store_in = 0;
 
-      skip_input (skip_whitespace (inptr));
+      ptr += skip_whitespace (ptr);
 
       /* Check what field we are looking at */
-      if (!strncasecmp (inptr, INFO_FILE_LABEL, strlen(INFO_FILE_LABEL)))
+      if (!strncasecmp (ptr, INFO_FILE_LABEL, strlen(INFO_FILE_LABEL)))
         {
-          skip_input (strlen(INFO_FILE_LABEL));
-          store_in = &dummy;
+          ptr += strlen (INFO_FILE_LABEL);
         }
-      else if (!strncasecmp (inptr, INFO_NODE_LABEL, strlen(INFO_NODE_LABEL)))
+      else if (!strncasecmp (ptr, INFO_NODE_LABEL, strlen(INFO_NODE_LABEL)))
         {
-          skip_input (strlen(INFO_NODE_LABEL));
-          store_in = &dummy;
+          ptr += strlen (INFO_NODE_LABEL);
         }
-      else if (!strncasecmp (inptr, INFO_PREV_LABEL, strlen(INFO_PREV_LABEL)))
+      else if (!strncasecmp (ptr, INFO_PREV_LABEL, strlen(INFO_PREV_LABEL)))
         {
-          skip_input (strlen(INFO_PREV_LABEL));
+          ptr += strlen (INFO_PREV_LABEL);
           store_in = &node->prev;
         }
-      else if (!strncasecmp (inptr, INFO_ALTPREV_LABEL, 
+      else if (!strncasecmp (ptr, INFO_ALTPREV_LABEL, 
                              strlen(INFO_ALTPREV_LABEL)))
         {
-          skip_input (strlen(INFO_ALTPREV_LABEL));
+          ptr += strlen (INFO_ALTPREV_LABEL);
           store_in = &node->prev;
         }
-      else if (!strncasecmp (inptr, INFO_NEXT_LABEL, strlen(INFO_NEXT_LABEL)))
+      else if (!strncasecmp (ptr, INFO_NEXT_LABEL, strlen(INFO_NEXT_LABEL)))
         {
-          skip_input (strlen(INFO_NEXT_LABEL));
+          ptr += strlen (INFO_NEXT_LABEL);
           store_in = &node->next;
         }
-      else if (!strncasecmp (inptr, INFO_UP_LABEL, strlen(INFO_UP_LABEL)))
+      else if (!strncasecmp (ptr, INFO_UP_LABEL, strlen(INFO_UP_LABEL)))
         {
-          skip_input (strlen(INFO_UP_LABEL));
+          ptr += strlen (INFO_UP_LABEL);
           store_in = &node->up;
         }
       else 
         {
-          store_in = &dummy;
+          store_in = 0;
           /* Not recognized - code below will skip to next comma */
         }
-        
-      skip_input (skip_whitespace (inptr));
+      ptr += skip_whitespace (ptr);
 
-      /* Separate at commas or newlines, so it will work for
-         filenames including full stops. */
-      /* TODO: Account for "(dir)" and "(DIR)". */
-      value_length = read_quoted_string (inptr, "\n\r\t,", 1, store_in);
+      /* Get length of a bracketed filename component. */
+      if (*ptr != '(')
+        value_length = 0;
+      else
+        value_length = read_bracketed_filename (ptr, 0);
 
-      free (dummy); dummy = 0;
-
-      /* Skip past value and any quoting or separating characters. */
-      skip_input (value_length);
-
-      if (*inptr == '\n')
+      /* Get length of node name, or filename if following "File:".  Note 
+         that .  is not included in the second argument here in order to 
+         support this character in file names. */
+      value_length += read_quoted_string (ptr + value_length,
+                                          "\n\r\t,", 1, &nodename);
+      if (store_in)
         {
-          skip_input (1);
-          break;
+          *store_in = xmalloc (value_length + 1);
+          strncpy (*store_in, ptr, value_length);
+          (*store_in)[value_length] = '\0';
         }
 
-      skip_input (1); /* Point after field terminator */
+      free (nodename);
+      ptr += value_length;
+
+      if (*ptr == '\n' || !*ptr)
+        break;
+
+      ptr += 1; /* Point after field terminator */
     }
 }
 
-/* Check if preceding word is a word like "see".  BASE points before PTR in
-   a block of allocated memory. */
-static int
-avoid_see_see (char *ptr, char *base)
-{
-  /* TODO: Only do this for English-language files. */
-  static char *words_like_see[] = {
-    "see", "See", "In", "in", "of", "also"
-  };
-  int i;
-  int word_len = 0;
-
-  if (ptr == base)
-    return 0;
-
-  /* Skip past whitespace, and then go to beginning of preceding word. */
-  ptr--;
-  while (ptr > base && (*ptr == ' ' || *ptr == '\n' || *ptr == '\r'
-                        || *ptr == '\t' || *ptr == '('))
-    ptr--;
-
-  while (ptr > base && !(*ptr == ' ' || *ptr == '\n' || *ptr == '\r'
-                         || *ptr == '\t' || *ptr == '(' ))
-    {
-      ptr--;
-      word_len++;
-    }
-
-  ptr++;
-
-  /* Check if it is in our list. */
-  for (i = 0; i < sizeof (words_like_see) / sizeof (char *); i++)
-    {
-      if (!strncmp (words_like_see[i], ptr, word_len))
-        return 1;
-    }
-  return 0;
-}
-
-/* Output, replace or hide text introducing a reference.  inptr starts on
+/* Output, replace or hide text introducing a reference.  INPTR starts on
    the first byte of a sequence introducing a reference and finishes on the
    first (non-whitespace) byte of the reference label. */
 static int
-scan_reference_marker (REFERENCE *entry)
+scan_reference_marker (REFERENCE *entry, int in_parentheses)
 {
   /* When preprocess_nodes is Off, we position the cursor on
      the "*" when moving between references. */
   if (!preprocess_nodes_p)
-    entry->start = inptr - input_start - output_bytes_difference;
+    {
+      if (rewrite_p)
+        entry->start = text_buffer_off(&output_buf);
+      else
+        entry->start = inptr - input_start;
+    }
 
   /* Check what we found based on first character of match */
   if (inptr[0] == '\n')
@@ -1248,8 +1209,6 @@ scan_reference_marker (REFERENCE *entry)
     copy_input_to_output (strlen ("\n* "));
   else
     {
-      int previous_word_is_like_see = 0;
-
       /* Only match "*Note" if it is followed by a whitespace character so that 
          it will not be recognized if, e.g., it is surrounded in inverted 
          commas. */
@@ -1264,23 +1223,28 @@ scan_reference_marker (REFERENCE *entry)
          and "See" in HTML and print.  @ref and @pxref output "*note "
          in Info format, and either nothing at all or "see" in HTML
          and print.  Unfortunately, there is no easy way to distinguish
-         between these latter two cases.  We must make do with
-         displayed manuals occasionally containing "See see" and the
-         like. */
+         between these latter two cases. */
       /* TODO: Internationalize these strings, but only if we know the
          language of the document. */
       if (inptr[1] == 'N')
-        write_extra_bytes_to_output ("See", 3);
-      else
         {
-          previous_word_is_like_see = avoid_see_see (inptr, input_start);
-
-          if (!previous_word_is_like_see)
-            write_extra_bytes_to_output ("see", 3);
+          write_extra_bytes_to_output ("See", 3);
+          in_parentheses = 1;
+        }
+      else if (in_parentheses)
+        {
+          write_extra_bytes_to_output ("see", 3);
+          /* Only output the "see" for input like "(*note ...)", which
+             would have come from a use of @pxref.  We used to output "see" for 
+             "*note" in more circumstances, with a list of words where to
+             suppress it (to avoid "see *note" turning into "see see"), but
+             such a list can't be complete or reliable.  It's better to remove 
+             it with more enthusiasm, then if the document writer wants a "see"
+             to appear, they can add one themselves. */
         }
 
       skip_input (strlen ("*Note"));
-      if (previous_word_is_like_see)
+      if (!in_parentheses)
         skip_input (skip_whitespace (inptr));
     }
 
@@ -1295,80 +1259,71 @@ scan_reference_marker (REFERENCE *entry)
    at the first character after the colon terminating the label.  Return 0 if
    invalid syntax is encountered. */
 static int
-scan_reference_label (REFERENCE *entry)
+scan_reference_label (REFERENCE *entry, int in_index)
 {
-  char *nl_ptr;
-  char *end;
-  char *label = 0;
-  long label_len;
+  int max_lines;
+  int len, label_len = 0;
+
+  /* Handle case of cross-reference like (FILE)NODE::. */
+  if (inptr[0] == '(')
+    label_len = read_bracketed_filename (inptr, &entry->filename);
 
   /* Search forward to ":" to get label name.  Cross-references may have
      a newline in the middle. */
   if (entry->type == REFERENCE_MENU_ITEM)
-    label_len = read_quoted_string (inptr, ":", 1, &label);
+    max_lines = 1;
   else
-    label_len = read_quoted_string (inptr, ":", 2, &label);
-    
-  if (label_len == 0)
+    max_lines = 2;
+  if (!in_index || inptr[label_len] == '\177')
     {
-      free (label);
-      return 0;
+      len = read_quoted_string (inptr + label_len, ":", max_lines,
+                                &entry->nodename);
+      if (!len)
+        return 0; /* Input invalid. */
+      label_len += len;
+    }
+  else
+    {
+      /* If in an index node, go forward to the last colon on the line
+         (not preceded by a newline, NUL or DEL).  This is in order to
+         support index entries containing colons.  This should work fine
+         as long as the node name does not contain a colon as well. */
+
+      char *p;
+      int n, m = 0;
+      p = inptr + label_len;
+
+      while (1)
+        {
+          n = strcspn (p, ":\n\177");
+          if (p[n] == ':')
+            {
+              m += n + 1;
+              p += n + 1;
+              continue;
+            }
+          break;
+        }
+      if (m == 0)
+        return 0; /* no : found */
+      label_len += m - 1;
     }
 
-  entry->label = label;
+  entry->label = xmalloc (label_len + 1);
+  memcpy (entry->label, inptr, label_len);
+  entry->label[label_len] = '\0';
   canonicalize_whitespace (entry->label);
 
-#ifdef QUOTE_NODENAMES
-  if (inptr[0] == '\177')
-    {
-      skip_input (1);
-      label_len -= 2;
-    }
-#endif
-
-  end = inptr + label_len;
-
-  underlining_on ();
-
-  /* Must start underlining first so that entry->start points to a printable
-     character.  Otherwise the cursor can end up in the previous column. */
   if (preprocess_nodes_p)
     entry->start = text_buffer_off (&output_buf);
 
-  /* Write text of label.  If there is a newline in the middle of
-     a reference label, turn off underlining until text starts again. */
-  while (inptr < end)
-    {
-      nl_ptr = strchr (inptr, '\n');
-      if (!nl_ptr || nl_ptr >= end)
-        break;
+  /* Write text of label. */
+  copy_input_to_output (label_len);
 
-      copy_input_to_output (nl_ptr - inptr);
-
-      /* Note we do this before the newline is output.  This way if
-         the first half of the label is on the bottom line of the
-         screen, underlining will not be left on. */
-      underlining_off ();
-
-      /* Output newline and any whitespace at start of next line. */
-      copy_input_to_output (1 + skip_whitespace (nl_ptr + 1));
-
-      underlining_on ();
-    }
-
-  /* Output rest of label */
-  copy_input_to_output (end - inptr);
-  underlining_off ();
-
-  if (preprocess_nodes_p)
+  if (rewrite_p)
     entry->end = text_buffer_off (&output_buf);
   else
-    entry->end = entry->start + label_len;
-
-#ifdef QUOTE_NODENAMES
-  if (inptr[0] == '\177')
-    skip_input (1);
-#endif
+    entry->end = inptr - input_start;
 
   /* Colon after label. */
   skip_input (1);
@@ -1386,19 +1341,6 @@ scan_reference_target (REFERENCE *entry, NODE *node, int in_parentheses)
 {
   int i;
 
-  /* If this reference entry continues with another ':' then the reference is
-     within the same file, and the nodename is the same as the label. */
-  if (*inptr == ':')
-    {
-      skip_input (1);
-      if (entry->type == REFERENCE_MENU_ITEM)
-        write_extra_bytes_to_output (" ", 1);
-
-      entry->filename = 0;
-      entry->nodename = xstrdup (entry->label);
-      return 1;
-    }
-
   /* This entry continues with a specific target.  Parse the
      file name and node name from the specification. */
 
@@ -1429,6 +1371,7 @@ scan_reference_target (REFERENCE *entry, NODE *node, int in_parentheses)
           else
             nl_off = 0;
         }
+      canonicalize_whitespace (entry->nodename);
 
       if (entry->filename)
         {
@@ -1550,14 +1493,6 @@ scan_reference_target (REFERENCE *entry, NODE *node, int in_parentheses)
         else
           entry->line_number = 0;
       }
-
-      if (preprocess_nodes_p && entry->line_number > 1)
-        /* Adjust line offset in file to one in displayed text.  This
-           does not work perfectly because we can't know exactly what
-           text will be inserted/removed: for example, due to expansion
-           of an image tag.  This subtracts 1 for a removed node information
-           line. */
-        entry->line_number--;
     }
 
   return 1;
@@ -1591,7 +1526,7 @@ scan_info_tag (NODE *node, int *in_index, FILE_BUFFER *fb)
 
   text_buffer_init (expansion);
 
-  if (tag_expand (&p1, expansion, in_index))
+  if (tag_expand (&p1, input_start + input_length, expansion, in_index))
     {
       if (*in_index)
         node->flags |= N_IsIndex;
@@ -1631,7 +1566,10 @@ scan_info_tag (NODE *node, int *in_index, FILE_BUFFER *fb)
 static char *
 forward_to_info_syntax (char *contents)
 {
-  while (contents < input_start + input_length)
+  /* Loop until just before the end of the input.  The '- 3' prevents us
+     accessing memory after the end of the input, and none of the strings we 
+     are looking for are shorter than 3 bytes. */
+  while (contents < input_start + input_length - 3)
     {
       /* Menu entry comes first to optimize for the case of looking through a 
          long index node. */
@@ -1652,8 +1590,9 @@ forward_to_info_syntax (char *contents)
 
    If FB is non-null, it is the file containing the node, and TAG_PTR is an 
    offset into FB->tags.  If the node contents are rewritten, adjust anchors
-   that occur in the node. */
-
+   that occur in the node and store adjusted value as TAG->nodestart_adjusted, 
+   otherwise simply copy TAG->nodestart to TAG->nodestart_adjusted for each 
+   anchor in the node. */
 void
 scan_node_contents (NODE *node, FILE_BUFFER *fb, TAG **tag_ptr)
 {
@@ -1678,7 +1617,8 @@ scan_node_contents (NODE *node, FILE_BUFFER *fb, TAG **tag_ptr)
       anchor_to_adjust = tag_ptr + 1;
       if (!*anchor_to_adjust)
         anchor_to_adjust = 0;
-      else if (*anchor_to_adjust && (*anchor_to_adjust)->nodelen != 0)
+      else if (*anchor_to_adjust
+               && (*anchor_to_adjust)->cache.nodelen != 0)
         anchor_to_adjust = 0;
 
       if (!node->subfile)
@@ -1702,13 +1642,14 @@ scan_node_contents (NODE *node, FILE_BUFFER *fb, TAG **tag_ptr)
   refs = calloc (1, sizeof *refs);
   refs_slots = 1;
 
+  parse_top_node_line (node);
+
   /* This should be the only time we assign to inptr in this function -
      all other assignment should be done with the helper functions above. */
   inptr = node->contents;
   input_start = node->contents;
   input_length = node->nodelen;
 
-  parse_top_node_line (node);
 
   while ((match = forward_to_info_syntax (inptr))
           && match < node->contents + node->nodelen)
@@ -1731,13 +1672,51 @@ scan_node_contents (NODE *node, FILE_BUFFER *fb, TAG **tag_ptr)
 
           save_conversion_state ();
           
-          if (!scan_reference_marker (entry)
-              || !scan_reference_label (entry)
-              || !scan_reference_target (entry, node, in_parentheses))
+          if (!scan_reference_marker (entry, in_parentheses))
+            goto not_a_reference;
+
+          if (!scan_reference_label (entry, in_index))
+            goto not_a_reference;
+
+          /* If this reference entry continues with another ':' then the target
+             of the reference is given by the label. */
+          if (*inptr == ':')
             {
+              int label_len;
+              skip_input (1);
+              if (entry->type == REFERENCE_MENU_ITEM)
+                write_extra_bytes_to_output (" ", 1);
+
+              /* Remove the DEL bytes from a label like "(FOO)^?BAR^?::". */
+              label_len = strlen (entry->label);
+              if (label_len >= 2 && entry->label[label_len - 1] == 0177)
+                {
+                  char *p = strchr (entry->label, '\177');
+                  memmove (p, p + 1, label_len - (p - entry->label) - 1);
+                  entry->label[label_len - 2] = '\0';
+                }
+            }
+          else
+            {
+              /* Proceed to read the rest of the reference. */
+              /* TODO: we should probably not allow references of the form 
+                 "(file)node1:node2." or "(file1)node1:(file2)node2", so
+                 bail out here if entry->filename is non-null. */
+
+              free (entry->filename); entry->filename = 0;
+              free (entry->nodename); entry->nodename = 0;
+              if (!scan_reference_target (entry, node, in_parentheses))
+                goto not_a_reference;
+            }
+
+          if (0)
+            {
+              char *cur_inptr;
+
+not_a_reference:
               /* This is not a menu entry or reference.  Do not add to our 
                  list. */
-              char *cur_inptr = inptr;
+              cur_inptr = inptr;
               reset_conversion ();
               copy_input_to_output (cur_inptr - inptr);
 
@@ -1748,7 +1727,7 @@ scan_node_contents (NODE *node, FILE_BUFFER *fb, TAG **tag_ptr)
           add_pointer_to_array (entry, refs_index, refs, refs_slots, 50);
         }
       /* Was "* Menu:" seen?  If so, search for menu entries hereafter. */
-      else if (!in_menu && !memcmp (match, INFO_MENU_LABEL,
+      else if (!in_menu && !strncmp (match, INFO_MENU_LABEL,
                                strlen (INFO_MENU_LABEL)))
         {
           in_menu = 1;
@@ -1789,6 +1768,17 @@ scan_node_contents (NODE *node, FILE_BUFFER *fb, TAG **tag_ptr)
          null, that is, the length. */
       node->nodelen = text_buffer_off (&output_buf) - 1;
     }
+  else if (fb && tag_ptr)
+    {
+      /* Set nodestart_adjusted for all of the anchors in this node. */
+      tag_ptr++;
+      while (*tag_ptr && (*tag_ptr)->cache.nodelen == 0)
+        {
+          (*tag_ptr)->nodestart_adjusted = (*tag_ptr)->nodestart
+                                             - output_bytes_difference;
+          tag_ptr++;
+        }
+    }
 }
 
 
@@ -1957,7 +1947,7 @@ text_buffer_space_left (struct text_buffer *buf)
 /* Run iconv using text buffer as output buffer. */
 size_t
 text_buffer_iconv (struct text_buffer *buf, iconv_t iconv_state,
-                   char **inbuf, size_t *inbytesleft)
+                   ICONV_CONST char **inbuf, size_t *inbytesleft)
 {
   size_t out_bytes_left;
   char *outptr;
@@ -1965,7 +1955,7 @@ text_buffer_iconv (struct text_buffer *buf, iconv_t iconv_state,
 
   outptr = text_buffer_base (buf) + text_buffer_off (buf);
   out_bytes_left = text_buffer_space_left (buf);
-  iconv_ret = iconv (iconv_to_output, inbuf, inbytesleft,
+  iconv_ret = iconv (iconv_state, inbuf, inbytesleft,
                      &outptr, &out_bytes_left);
 
   text_buffer_off (buf) = outptr - text_buffer_base (buf);    
