@@ -222,6 +222,7 @@ $result_trees{'block_commands'} = {
         {
           'contents' => [
             {
+              'parent' => {},
               'text' => ' ',
               'type' => 'empty_spaces_before_argument'
             },
@@ -304,12 +305,7 @@ $result_trees{'block_commands'} = {
           'cmdname' => 'caption',
           'contents' => [],
           'extra' => {
-            'float' => {},
-            'spaces_before_argument' => {
-              'parent' => {},
-              'text' => '',
-              'type' => 'empty_spaces_before_argument'
-            }
+            'float' => {}
           },
           'line_nr' => {
             'file_name' => '',
@@ -385,7 +381,7 @@ $result_trees{'block_commands'} = {
           'content' => [
             {}
           ],
-          'normalized' => 'a-float'
+          'normalized' => 'a float'
         }
       },
       'line_nr' => {
@@ -440,6 +436,7 @@ $result_trees{'block_commands'}{'contents'}[5]{'args'}[0]{'contents'}[0]{'extra'
 $result_trees{'block_commands'}{'contents'}[5]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'block_commands'}{'contents'}[5]{'args'}[0];
 $result_trees{'block_commands'}{'contents'}[5]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'block_commands'}{'contents'}[5]{'args'}[0];
 $result_trees{'block_commands'}{'contents'}[5]{'args'}[0]{'parent'} = $result_trees{'block_commands'}{'contents'}[5];
+$result_trees{'block_commands'}{'contents'}[5]{'args'}[1]{'contents'}[0]{'parent'} = $result_trees{'block_commands'}{'contents'}[5]{'args'}[1];
 $result_trees{'block_commands'}{'contents'}[5]{'args'}[1]{'contents'}[1]{'parent'} = $result_trees{'block_commands'}{'contents'}[5]{'args'}[1];
 $result_trees{'block_commands'}{'contents'}[5]{'args'}[1]{'contents'}[2]{'parent'} = $result_trees{'block_commands'}{'contents'}[5]{'args'}[1];
 $result_trees{'block_commands'}{'contents'}[5]{'args'}[1]{'parent'} = $result_trees{'block_commands'}{'contents'}[5];
@@ -454,7 +451,6 @@ $result_trees{'block_commands'}{'contents'}[5]{'contents'}[3]{'args'}[0]{'conten
 $result_trees{'block_commands'}{'contents'}[5]{'contents'}[3]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'block_commands'}{'contents'}[5]{'contents'}[3]{'args'}[0];
 $result_trees{'block_commands'}{'contents'}[5]{'contents'}[3]{'args'}[0]{'parent'} = $result_trees{'block_commands'}{'contents'}[5]{'contents'}[3];
 $result_trees{'block_commands'}{'contents'}[5]{'contents'}[3]{'extra'}{'float'} = $result_trees{'block_commands'}{'contents'}[5];
-$result_trees{'block_commands'}{'contents'}[5]{'contents'}[3]{'extra'}{'spaces_before_argument'}{'parent'} = $result_trees{'block_commands'}{'contents'}[5]{'contents'}[3]{'args'}[0];
 $result_trees{'block_commands'}{'contents'}[5]{'contents'}[3]{'parent'} = $result_trees{'block_commands'}{'contents'}[5];
 $result_trees{'block_commands'}{'contents'}[5]{'contents'}[4]{'parent'} = $result_trees{'block_commands'}{'contents'}[5];
 $result_trees{'block_commands'}{'contents'}[5]{'contents'}[5]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'block_commands'}{'contents'}[5]{'contents'}[5];
@@ -511,18 +507,14 @@ $result_errors{'block_commands'} = [];
 
 
 $result_floats{'block_commands'} = {
-  'a-float' => [
+  'a float' => [
     {
       'cmdname' => 'float',
       'extra' => {
         'caption' => {
           'cmdname' => 'caption',
           'extra' => {
-            'float' => {},
-            'spaces_before_argument' => {
-              'text' => '',
-              'type' => 'empty_spaces_before_argument'
-            }
+            'float' => {}
           }
         },
         'end_command' => {
@@ -540,15 +532,15 @@ $result_floats{'block_commands'} = {
               'text' => 'a float'
             }
           ],
-          'normalized' => 'a-float'
+          'normalized' => 'a float'
         }
       },
       'number' => 1
     }
   ]
 };
-$result_floats{'block_commands'}{'a-float'}[0]{'extra'}{'caption'}{'extra'}{'float'} = $result_floats{'block_commands'}{'a-float'}[0];
-$result_floats{'block_commands'}{'a-float'}[0]{'extra'}{'end_command'}{'extra'}{'command'} = $result_floats{'block_commands'}{'a-float'}[0];
+$result_floats{'block_commands'}{'a float'}[0]{'extra'}{'caption'}{'extra'}{'float'} = $result_floats{'block_commands'}{'a float'}[0];
+$result_floats{'block_commands'}{'a float'}[0]{'extra'}{'end_command'}{'extra'}{'command'} = $result_floats{'block_commands'}{'a float'}[0];
 
 
 
@@ -590,7 +582,7 @@ $result_converted{'xml'}->{'block_commands'} = '
 <para>in quotation
 </para></quotation>
 
-<float name="b-float" type="a-float" number="1" spaces=" " endspaces=" "><floattype>a float</floattype><floatname spaces=" ">b float</floatname>
+<float name="b-float" type="a float" number="1" spaces=" " endspaces=" "><floattype>a float</floattype><floatname spaces=" ">b float</floatname>
 <para>In float
 </para>
 
