@@ -1381,15 +1381,6 @@ $result_errors{'special_docbook_unnumbered'} = [
     'text' => 'node next `preface\' in menu `acknowledgements\' and in sectioning `colophon\' differ',
     'type' => 'warning'
   },
-  {
-    'error_line' => ':23: warning: unreferenced node `colophon\'
-',
-    'file_name' => '',
-    'line_nr' => 23,
-    'macro' => '',
-    'text' => 'unreferenced node `colophon\'',
-    'type' => 'warning'
-  },
   {
     'error_line' => ':23: warning: node `acknowledgements\' is next for `colophon\' in sectioning but not in menu
 ',
