@@ -86,8 +86,7 @@ $result_trees{'pxref_test'} = {
                       'parent' => {},
                       'text' => 'in pxref'
                     }
-                  ],
-                  'normalized' => 'in-pxref'
+                  ]
                 }
               },
               'line_nr' => {
@@ -152,8 +151,7 @@ $result_trees{'pxref_test'} = {
                       'parent' => {},
                       'text' => 'in pxref'
                     }
-                  ],
-                  'normalized' => 'in-pxref'
+                  ]
                 }
               },
               'line_nr' => {},
@@ -197,8 +195,7 @@ $result_trees{'pxref_test'} = {
                       'parent' => {},
                       'text' => 'n'
                     }
-                  ],
-                  'normalized' => 'n'
+                  ]
                 }
               },
               'line_nr' => {
@@ -263,8 +260,7 @@ $result_trees{'pxref_test'} = {
                       'parent' => {},
                       'text' => 'n'
                     }
-                  ],
-                  'normalized' => 'n'
+                  ]
                 }
               },
               'line_nr' => {},
