@@ -1101,31 +1101,6 @@ $result_nodes{'sc_in_menu'} = {
     'extra' => {
       'normalized' => 'NODE'
     },
-    'menu_child' => {
-      'extra' => {
-        'manual_content' => [
-          {
-            'text' => 'dir'
-          }
-        ],
-        'normalized' => 'EXAMPLE-NODE'
-      }
-    },
-    'menus' => [
-      {
-        'cmdname' => 'menu',
-        'extra' => {
-          'end_command' => {
-            'cmdname' => 'end',
-            'extra' => {
-              'command' => {},
-              'command_argument' => 'menu',
-              'text_arg' => 'menu'
-            }
-          }
-        }
-      }
-    ],
     'node_prev' => {},
     'node_up' => {}
   },
@@ -1157,7 +1132,6 @@ $result_nodes{'sc_in_menu'} = {
     'type' => 'top_node_up'
   }
 };
-$result_nodes{'sc_in_menu'}{'menu_child'}{'menus'}[0]{'extra'}{'end_command'}{'extra'}{'command'} = $result_nodes{'sc_in_menu'}{'menu_child'}{'menus'}[0];
 $result_nodes{'sc_in_menu'}{'menu_child'}{'node_prev'} = $result_nodes{'sc_in_menu'};
 $result_nodes{'sc_in_menu'}{'menu_child'}{'node_up'} = $result_nodes{'sc_in_menu'};
 $result_nodes{'sc_in_menu'}{'menus'}[0]{'extra'}{'end_command'}{'extra'}{'command'} = $result_nodes{'sc_in_menu'}{'menus'}[0];
@@ -1174,16 +1148,6 @@ $result_menus{'sc_in_menu'} = {
     'extra' => {
       'normalized' => 'NODE'
     },
-    'menu_child' => {
-      'extra' => {
-        'manual_content' => [
-          {
-            'text' => 'dir'
-          }
-        ],
-        'normalized' => 'EXAMPLE-NODE'
-      }
-    },
     'menu_up' => {},
     'menu_up_hash' => {
       'Top' => 1
@@ -1192,7 +1156,17 @@ $result_menus{'sc_in_menu'} = {
 };
 $result_menus{'sc_in_menu'}{'menu_child'}{'menu_up'} = $result_menus{'sc_in_menu'};
 
-$result_errors{'sc_in_menu'} = [];
+$result_errors{'sc_in_menu'} = [
+  {
+    'error_line' => ':19: warning: @menu in invalid context
+',
+    'file_name' => '',
+    'line_nr' => 19,
+    'macro' => '',
+    'text' => '@menu in invalid context',
+    'type' => 'warning'
+  }
+];
 
 
 
@@ -1230,16 +1204,16 @@ $result_converted{'html'}->{'sc_in_menu'} = '<!DOCTYPE html PUBLIC "-//W3C//DTD
 <style type="text/css">
 <!--
 a.summary-letter {text-decoration: none}
+blockquote.indentedblock {margin-right: 0em}
+blockquote.smallindentedblock {margin-right: 0em; font-size: smaller}
 blockquote.smallquotation {font-size: smaller}
 div.display {margin-left: 3.2em}
 div.example {margin-left: 3.2em}
-div.indentedblock {margin-left: 3.2em}
 div.lisp {margin-left: 3.2em}
 div.smalldisplay {margin-left: 3.2em}
 div.smallexample {margin-left: 3.2em}
-div.smallindentedblock {margin-left: 3.2em; font-size: smaller}
 div.smalllisp {margin-left: 3.2em}
-kbd {font-style:oblique}
+kbd {font-style: oblique}
 pre.display {font-family: inherit}
 pre.format {font-family: inherit}
 pre.menu-comment {font-family: serif}
@@ -1248,10 +1222,9 @@ pre.smalldisplay {font-family: inherit; font-size: smaller}
 pre.smallexample {font-size: smaller}
 pre.smallformat {font-family: inherit; font-size: smaller}
 pre.smalllisp {font-size: smaller}
-span.nocodebreak {white-space:nowrap}
-span.nolinebreak {white-space:nowrap}
-span.roman {font-family:serif; font-weight:normal}
-span.sansserif {font-family:sans-serif; font-weight:normal}
+span.nolinebreak {white-space: nowrap}
+span.roman {font-family: initial; font-weight: normal}
+span.sansserif {font-family: sans-serif; font-weight: normal}
 ul.no-bullet {list-style: none}
 -->
 </style>
@@ -1259,7 +1232,7 @@ ul.no-bullet {list-style: none}
 
 </head>
 
-<body lang="en" bgcolor="#FFFFFF" text="#000000" link="#0000FF" vlink="#800080" alink="#FF0000">
+<body lang="en">
 
 <a name="Top"></a>
 <div class="header">
@@ -1272,6 +1245,7 @@ Next: <a href="#NODE" accesskey="n" rel="next"><small>NODE</small></a>, Up: <a h
 <tr><td align="left" valign="top">&bull; <a href="#NODE" accesskey="1"><small>VALUE</small></a>:</td><td>&nbsp;&nbsp;</td><td align="left" valign="top"><small>DESCRIP TION</small>
 </td></tr>
 <tr><th colspan="3" align="left" valign="top"><pre class="menu-comment">
+
 MENU COMMENT
 
 </pre><div class="example">
@@ -1285,7 +1259,7 @@ MENU-EXAMPLE COMMENT
 <a name="NODE"></a>
 <div class="header">
 <p>
-Previous: <a href="#Top" accesskey="p" rel="previous">Top</a>, Up: <a href="#Top" accesskey="u" rel="up">Top</a> &nbsp; </p>
+Previous: <a href="#Top" accesskey="p" rel="prev">Top</a>, Up: <a href="#Top" accesskey="u" rel="up">Top</a> &nbsp; </p>
 </div>
 <h4 class="node-heading"><small>NODE</small></h4>
 
@@ -1293,6 +1267,7 @@ Previous: <a href="#Top" accesskey="p" rel="previous">Top</a>, Up: <a href="#Top
 <table class="menu" border="0" cellspacing="0"><tr><td>
 <pre class="menu-preformatted">&bull; EXAMPLE VALUE:<a href="dir.html#EXAMPLE-NODE" accesskey="1">(dir)EXAMPLE NODE</a>.   EXAMPLE DESCRIP TION
 </pre><pre class="menu-comment">
+
 EXAMPLE COMMENT
 </pre></td></tr></table>
 </div>
