@@ -33,6 +33,12 @@ $result_trees{'inter_item_commands_in_table_in_example'} = {
                 },
                 {
                   'cmdname' => 'var',
+                  'contents' => [],
+                  'line_nr' => {
+                    'file_name' => '',
+                    'line_nr' => 2,
+                    'macro' => ''
+                  },
                   'parent' => {},
                   'type' => 'command_as_argument'
                 },
@@ -136,7 +142,6 @@ $result_trees{'inter_item_commands_in_table_in_example'} = {
                                   'in_code' => 0,
                                   'index_at_command' => 'cindex',
                                   'index_name' => 'cp',
-                                  'index_prefix' => 'c',
                                   'index_type_command' => 'cindex',
                                   'key' => 'index entry between item and itemx',
                                   'number' => 1
@@ -426,11 +431,7 @@ $result_trees{'inter_item_commands_in_table_in_example'} = {
             'end_command' => {},
             'spaces_after_command' => {}
           },
-          'line_nr' => {
-            'file_name' => '',
-            'line_nr' => 2,
-            'macro' => ''
-          },
+          'line_nr' => {},
           'parent' => {}
         },
         {
@@ -567,6 +568,7 @@ $result_trees{'inter_item_commands_in_table_in_example'}{'contents'}[0]{'content
 $result_trees{'inter_item_commands_in_table_in_example'}{'contents'}[0]{'contents'}[1]{'extra'}{'command_as_argument'} = $result_trees{'inter_item_commands_in_table_in_example'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'}[1];
 $result_trees{'inter_item_commands_in_table_in_example'}{'contents'}[0]{'contents'}[1]{'extra'}{'end_command'} = $result_trees{'inter_item_commands_in_table_in_example'}{'contents'}[0]{'contents'}[1]{'contents'}[2];
 $result_trees{'inter_item_commands_in_table_in_example'}{'contents'}[0]{'contents'}[1]{'extra'}{'spaces_after_command'} = $result_trees{'inter_item_commands_in_table_in_example'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0];
+$result_trees{'inter_item_commands_in_table_in_example'}{'contents'}[0]{'contents'}[1]{'line_nr'} = $result_trees{'inter_item_commands_in_table_in_example'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'}[1]{'line_nr'};
 $result_trees{'inter_item_commands_in_table_in_example'}{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'inter_item_commands_in_table_in_example'}{'contents'}[0];
 $result_trees{'inter_item_commands_in_table_in_example'}{'contents'}[0]{'contents'}[2]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'inter_item_commands_in_table_in_example'}{'contents'}[0]{'contents'}[2];
 $result_trees{'inter_item_commands_in_table_in_example'}{'contents'}[0]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'inter_item_commands_in_table_in_example'}{'contents'}[0]{'contents'}[2]{'args'}[0];
@@ -633,6 +635,7 @@ $result_converted{'html_text'}->{'inter_item_commands_in_table_in_example'} = '<
 <dd><pre class="example"><a name="index-index-entry-between-item-and-itemx"></a></pre></dd>
 <dt><tt><var>b</var></tt></dt>
 <dd><pre class="example">
+
 </pre></dd>
 <dt><tt><var>c</var></tt></dt>
 <dd><pre class="example">l--ine
